@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 766 $
+# Revision: $Rev: 773 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -22,17 +22,21 @@
 ############################################################################
 
 #-- imports --------------------------------------------------------------------
+#-- qt imports
+from qt import SIGNAL, QPixmap, QImage
 
 #-- Python imports
 import logging
 
+from os.path import exists as fexists, join as fjoin, splitext
 
 #-- own imports
 from ExportDialogBase import ExportDialogBase
-from Settings import getPreferences
+from Settings import getPreferences, Settings, updatePreferences
 from misc import Date2YMD
 from AMCFile33 import AMCRecord33
 
+
 #-- preferences ----------------------------------------------------------------
 pref = getPreferences(__name__)
 
@@ -85,13 +89,21 @@ class ExportDialog(ExportDialogBase):
         self.log.setLevel( pref['logLevel'] )
 
         # runtime variables
-        self.exportList = []
+        self.templateList = []
         self.sortFields = []
+        self.templatedir = fjoin(Settings().userdir, 'templates')
 
-        # load available export scripts
+        # load available export scripts 
         for key in pref['export'].keys():
-            self.exportFilterComboBox.insertItem(key)
-            self.exportList.append(key)
+            # ignore non .st files
+            if (splitext(key)[1] != '.st'): continue
+            template = fjoin(self.templatedir, key)
+            if (not fexists(template)):
+                log.error("Template '%s' specified in config file, but does not exist in '%s'", key, self.templatedir)
+                continue
+            self.exportTemplateComboBox.insertItem(key)
+            self.templateList.append(key)
+
 
         # load available sort criterea
         record = AMCRecord33()
@@ -106,13 +118,47 @@ class ExportDialog(ExportDialogBase):
 
         # set default sort key
         self.sortComboBox.setCurrentItem(defaultIndex)
+        # load default filter chain text to lineedit
+        self.exportTemplateChanged(self.exportTemplateComboBox.currentItem())
+        # set focus to export template combobox
+        self.exportTemplateComboBox.setFocus()
+
+        # connect signals
+        self.connect(self.exportTemplateComboBox, SIGNAL('activated(int)'), self.exportTemplateChanged)
+        self.connect(self.savePushButton, SIGNAL('pressed()'), self.saveFilterChain)
+
+
+    def saveFilterChain(self):
+        """executed when 'save' pushbutton is pressed"""
+        text = unicode(self.filterChainLineEdit.text())
+        template = self.templateList[self.exportTemplateComboBox.currentItem()]
+        tmp_old = pref['export'][template]
+        tmp_new = (text, tmp_old[1])
+        # propagate changes
+        Settings()['export'][template] = tmp_new
+        updatePreferences()
+
+
+    def exportTemplateChanged(self, index):
+        """executed when user changes export template"""
+        template = self.templateList[index]
+        template_options = pref['export'][template]
+        image_preview = fjoin(self.templatedir, splitext(template)[0])+".png"
+        if (fexists(image_preview)):
+            self.log.debug("Loading preview image %s", image_preview)
+            img = QImage(image_preview).smoothScale(100,100, QImage.ScaleMin)
+            self.previewPixmapLabel.setPixmap(QPixmap(img))
+        else:
+            self.log.warning("No preview image found for template %s", template)
+            self.previewPixmapLabel.clear()
+        self.filterChainLineEdit.setText(template_options[0])
 
 
     def getOptions(self):
         """return tuple of selected options"""
         # export filter
-        exportFilterIdx = self.exportFilterComboBox.currentItem()
-        exportFilter = self.exportList[exportFilterIdx]
+        exportTemplateIdx = self.exportTemplateComboBox.currentItem()
+        exportTemplate = self.templateList[exportTemplateIdx]
 
         # sort criterea
         sortFieldIdx = self.sortComboBox.currentItem()
@@ -128,7 +174,7 @@ class ExportDialog(ExportDialogBase):
         if (self.descendingRadioButton.isChecked()):
             ascending = False
 
-        return (exportFilter, sortField, allEntries, not ascending)
+        return (exportTemplate, sortField, allEntries, not ascending)
 
                                 
 
