@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 759 $
+# Revision: $Rev: 768 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -26,7 +26,8 @@
 from qt import QImage, QPixmap, QLabel, QGridLayout, PYSIGNAL
 from qt import QImageDrag, QDragObject, QSizePolicy, QPopupMenu, QIconSet
 from qt import QCursor, QPixmap, QFileDialog, QMessageBox, QFileDialog
-from qt import QDockWindow
+from qt import QDockWindow, QToolBar, QSpacerItem, QSizePolicy
+from qt import QToolButton, QSize, SIGNAL
 
 
 #-- Python imports
@@ -384,15 +385,33 @@ class PicturePreview(PicturePreviewBase):
         self.link_pix.loadFromData(link_data, "PNG")
         self.embed_pix = QPixmap()
         self.embed_pix.loadFromData(embed_data, "PNG")
-        
-        gridLayoutLabel = QGridLayout( self, 1,1 )
-        gridLayoutLabel.addWidget( self.labelImage, 0,0 )
+
+        self.linkPictureAction.setIconSet(QIconSet(self.link_pix))
+        self.embedPictureAction.setIconSet(QIconSet(self.embed_pix))
+        self.copyAction.setIconSet(QIconSet(self.copy_pix))
+        self.pasteAction.setIconSet(QIconSet(self.paste_pix))
+        self.saveAsAction.setIconSet(QIconSet(self.saveAs_pix))
+        self.deleteAction.setIconSet(QIconSet(self.recycle_pix))
+
+        self.setCentralWidget(self.labelImage)
+
+        self.topDock().close(False)
+        self.rightDock().close(False)
+        self.bottomDock().close(False)
+        self.statusBar().close(False)
 
         self.setCaption("picture")
 
         # connect signal to detect dropped images
         self.connect(self.labelImage, PYSIGNAL("imageDropped"), self.onImageDropped)
 
+        self.connect(self.linkPictureAction, SIGNAL('pressed()'), self.linkPicture)
+        self.connect(self.embedPictureAction, SIGNAL('pressed()'), self.embedPicture)
+        self.connect(self.copyAction, SIGNAL('pressed()'), self.copyPicture)
+        self.connect(self.pasteAction, SIGNAL('pressed()'), self.pastePicture)
+        self.connect(self.saveAsAction, SIGNAL('pressed()'), self.saveAsPicture)
+        self.connect(self.deleteAction, SIGNAL('pressed()'), self.deletePicture)
+
 
     #-- event handlers ---------------------------------------------------------
     def resizeEvent(self, e):
@@ -408,7 +427,7 @@ class PicturePreview(PicturePreviewBase):
             menu.insertItem(self.tr("Picture Menu"), None, 1)
             menu.insertSeparator()
             menu.insertItem(QIconSet(self.link_pix), self.tr("Link picture"), self.linkPicture, 0, 2)
-            menu.insertItem(QIconSet(self.embed_pix), self.tr("Embedd picture"), self.embedPicture, 0, 3)
+            menu.insertItem(QIconSet(self.embed_pix), self.tr("Embed picture"), self.embedPicture, 0, 3)
             menu.insertSeparator()
             if (self.img): menu.insertItem(QIconSet(self.copy_pix), self.tr("Copy"), self.copyPicture, 0, 4)
             menu.insertItem(QIconSet(self.paste_pix), self.tr("Paste"), self.pastePicture, 0, 5)
@@ -425,7 +444,7 @@ class PicturePreview(PicturePreviewBase):
             return
             
         # spawn unscaled picture
-        if ((self.img != None) and (self.enableZoom)):
+        if ((self.img != None) and (self.enableZoom) and (e.pos().x() > self.toolBar.width())):
             dlg = PictureDialog(self.img, modal=False)
             dlg.exec_loop()
 
@@ -436,10 +455,9 @@ class PicturePreview(PicturePreviewBase):
         filename = QFileDialog.getOpenFileName(
             pref['defaultPath'], self.tr("Images (*.bmp; *.jpeg; *.pbm; *.png; *.ppm *.xbm; *.xpm)"),
             self, None, self.tr("Select image"))
-        # exit on abort
-        if (filename == None): return
-        # converto to non QString object
         filename = unicode(filename)
+        # exit on abort
+        if (filename == ''): return
 
         if (self._loadImage(filename)):
             # try to remove absolute portion of path - if prefix is <basedir>
@@ -466,11 +484,12 @@ class PicturePreview(PicturePreviewBase):
         filename = QFileDialog.getOpenFileName(
             pref['defaultPath'], self.tr("Images (*.bmp; *.jpeg; *.pbm; *.png; *.ppm *.xbm; *.xpm)"),
             self, None, self.tr("Select image"))
-        # exit on abort
-        if (filename == None): return
-        # converto to non QString object
         filename = unicode(filename)
-        self.log.info("Embedding image file %s", filename)
+
+        # exit on abort
+        if (filename == ''): return
+
+        self.log.info("Embeding image file %s", filename)
 
         # load picture
         if (self._loadImage(filename)):
@@ -493,11 +512,11 @@ class PicturePreview(PicturePreviewBase):
         filename = QFileDialog.getSaveFileName(
             pref['defaultPath'], self.tr("Images (*.bmp; *.jpeg; *.pbm; *.png; *.ppm *.xbm; *.xpm)"),
             self, None, self.tr("Save file as"))
-        # exit on abort
-        if (filename == None): return
-        # convert to non QString object
         filename = unicode(filename)
 
+        # exit on abort
+        if (filename == ''): return
+
         # construct filename
         filenameTuple = splitext(filename)
         imgType = splitext(filename)[1].upper()[1:]
@@ -550,6 +569,10 @@ class PicturePreview(PicturePreviewBase):
         if (self.img == None):
             self.log.warning("Not copying picture: no picture available")
         self.copyImg = self.img
+
+        # popup is enabled/disabled automatically
+        # but enable toolbar button, too
+        self.pasteAction.setEnabled(True)
         
 
     def pastePicture(self):
@@ -574,7 +597,7 @@ class PicturePreview(PicturePreviewBase):
 
 
     def imageSize(self):
-        """returns QSize of the embedded image, None otherwise"""
+        """returns QSize of the embeded image, None otherwise"""
         if (self.img):
             return self.img.size()
         else:
@@ -638,7 +661,7 @@ class PicturePreview(PicturePreviewBase):
 
 
     def _embedImage(self):
-        """decodes internal image to be saved embedded in the record"""
+        """decodes internal image to be saved embeded in the record"""
         # extract image from QImage 
         data = IODeviceBuffer()
             
@@ -647,7 +670,7 @@ class PicturePreview(PicturePreviewBase):
             self.record['embeddedImage'] = ""
             self.record['picture'] = u""                
         elif ( self.img.save(data, pref['imageFormat']) ):
-            self.log.debug("Saving embedded image: %d bytes", data.size())
+            self.log.debug("Saving embeded image: %d bytes", data.size())
             self.record['embeddedImage'] = data.readAll()
             fmt = pref['imageFormat']
             if (fmt == 'JPEG'): fmt = 'JPG' # AMC requires 'jpg' instead of 'jpeg'
@@ -709,7 +732,7 @@ class PicturePreview(PicturePreviewBase):
 
     def defaultImageDecode(self):
         """decodes internal image to be saved in the record"""
-        # handle embedded image
+        # handle embeded image
         if (pref['embeddedImage']):
             self._embedImage()
             
@@ -785,13 +808,13 @@ class PicturePreview(PicturePreviewBase):
         if (self.record == None):
             self.img = None
             
-        # record has embedded image   
+        # record has embeded image   
         elif (len(self.record['embeddedImage']) > MIN_PICTURE_SIZE):
-            self.log.debug("Loading embedded image")
+            self.log.debug("Loading embeded image")
             self.img = QImage()
             ok = self.img.loadFromData(self.record['embeddedImage'])
             if (not ok):
-                self.log.error("Could not identify embedded image data")
+                self.log.error("Could not identify embeded image data")
                 self.img = None
                 
         # try loading picture from reference
@@ -819,7 +842,7 @@ class PicturePreview(PicturePreviewBase):
         # - from http (or whatever openResource loads)
         # - from (correctly) linked image
         # - from temp linked image
-        # - embedded data
+        # - embeded data
         # => 2 of 4 reasonst which need explicid decoding
         # image is automatically decoded on drag&drop
         # main program loop must image decode manually when
@@ -857,6 +880,6 @@ if (__name__ == "__main__"):
     a.exec_loop()
 
     tmp = w.getRecord()
-    print "len embedded: ",len(tmp['embeddedImage'])
+    print "len embeded: ",len(tmp['embeddedImage'])
     print "picture:  ",tmp['picture']
 
