@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 766 $
+# Revision: $Rev: 768 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -290,11 +290,14 @@ class RecordList(RecordListBase):
 
 #-- testroutine ----------------------------------------------------------------
 if (__name__ == "__main__"):
-    from qt import QApplication, QObject, SLOT
+    from qt import QApplication, QObject, SLOT, QMainWindow
 
     a = QApplication(sys.argv)
     QObject.connect(a,SIGNAL("lastWindowClosed()"),a,SLOT("quit()"))
 
+    b = QMainWindow()
+    a.setMainWidget(b)
+
     # need logging handlers for testing
     log = logging.getLogger("")
     hdlr = logging.StreamHandler()
@@ -303,7 +306,7 @@ if (__name__ == "__main__"):
     log.addHandler(hdlr) 
     log.setLevel(pref['logLevel'])
 
-    w = RecordList(".")
+    w = RecordList(".", b)
 
     from AMCFile33 import AMCFile33
     f = AMCFile33(u"/home/merkosh/src/Film- Mp3- Hörspiellisten/Filme/LMC/Filme.amc", "rb")
@@ -312,8 +315,8 @@ if (__name__ == "__main__"):
     w.add( rec )
     w.focusFirst()
 
-    a.setMainWidget(w)
-    w.show()
+    b.setCentralWidget(w)
+    b.show()
 #    w.setCurrentrecord(rec)
 
     a.exec_loop()
