@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 766 $
+# Revision: $Rev: 773 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -38,7 +38,7 @@ import defaults
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 766 $
+# Revision: $Rev: 773 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -389,9 +389,38 @@ defaultScript = %(defaultScript)s
 
 # export holds a list of available export scripts and templates that are
 # available through the export dialog.
+# Upon opening the export dialog, all system wide templates are copied
+# to $HOME/.lmc/tempaltes, if they do not already exist. Templates
+# end on '.st' and contain StringTemplate group files. The template
+# 'main(file,record)' is parsed by templateParser.py to replace fields
+# from the AMC file and each individual records. Please refer to the
+# Python StringTempalte homepage for information on how to use
+# StringTemplates: http://www.stringtemplate.org/doc/python-doc.html
+#
+# Valid template fields are record keys from AMCRecord33.
 # 
+# The format is as follows: export is a dict, with each key being the
+# basename of a template. This template is processed by the template
+# engine in /tmp, which produces an output file of with the same name
+# as the template, but without the suffix (i.e. simple_pdf.st ->
+# simple_pdf). 
+# The value of the dict is a 2-tuple. The first entry contains a string
+# in which the sequence '$1' is replaced by the output filename of the
+# template engine. This string is executed in a user shell (taken from
+# $SHELL environment variable. The second entry contains the full
+# path to the output file generated in the first entry.
+#
+# The template directory may contain .png files which match the name
+# of the template. If it exists, it will be used as a preview picture
+# in the export dialog.
+# i.e. simple_pdf.st, simple_pdf.png
+
 export = %(export)s
 
+# exportDefaultSortKey is a text field, containing the record key
+# by which the entries are sorted bevore parsing the tempalte file.
+# default: mediaLabel
+
 exportDefaultSortKey = %(exportDefaultSortKey)s
 
 #-- EOF --
@@ -653,6 +682,27 @@ class _Settings2(_Settings1):
         return defs
         
 
+class _Settings3(_Settings2):
+    """extends previous settings object by a new log class
+
+    This was introduced with log format version 0.2.
+    """
+    def __init__(self):
+        super(_Settings3, self).__init__()
+
+
+    def selfUpdate(self, toDict, fromDict):
+        super(_Settings3, self).selfUpdate(toDict, fromDict)
+
+        # add new log class
+        if (self['version'] == '0.2'):
+            self['version'] = '0.3'
+
+            # add export settings
+            self['export'] = {u'simple_pdf.st': (u'pdflatex $1 && pdflatex $1', u'/tmp/$1.pdf'),
+                              u'text_csv.st': (u'mv $1 $1.csv', u'/tmp/$1.csv') }
+
+
 
 #-- main class for config format -----------------------------------------------
 # If the configuration format needs to be changed and in order to keep
@@ -664,7 +714,7 @@ class _Settings2(_Settings1):
 # a way that when calling the parent's asText() or update() method the
 # interface to the old-style configuration is maintained and the return
 # value reflects the current state of the configuration.
-class _Settings(_Settings2):
+class _Settings(_Settings3):
     """encapsulates loading, updating and saving of global program defaults
 
     Compared to the _Pref class, this contains the global, cross-class
