@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 766 $
+# Revision: $Rev: 770 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -24,13 +24,13 @@ import os
 from os.path import join as fjoin, exists as fexists
 
 
-pythondir = "${prefix}/lib/python2.4/site-packages".replace('${prefix}', "/usr")
+pythondir = "${prefix}/lib/python2.4/site-packages".replace('${prefix}', "/usr/local")
 installdir = fjoin(pythondir, "lmc")
 
 if (os.getcwd() == "/home/merkosh/src/lmc/src"):
 	installdir = "/home/merkosh/src/lmc/src"
 
-version = "0.14"
+version = "0.15"
 scriptdir = fjoin(installdir, "scripts")
 resourcedir = fjoin(installdir, "resources")
 templatedir = fjoin(installdir, "templates")
@@ -40,3 +40,5 @@ use_listviewsort = ("yes" == "yes")
 have_eject = ("/usr/bin/eject" != "no")
 have_tcprobe = ("/home/merkosh/usr/bin/tcprobe" != "no")
 
+# python executable
+python = "/usr/bin/python2.4"
