@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 766 $
+# Revision: $Rev: 773 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -49,15 +49,17 @@ hdlr.setFormatter(formatter)
 log.addHandler(hdlr) 
 log.setLevel(logging.DEBUG)             # default log level
 
+
+from defaults import scriptdir, templatedir, installdir, version
+
 # output program text-logo
-log.info("moviefly  $Rev: 766 $ (c) by Uwe Mayer")
+log.info("moviefly v%s  (c) by Uwe Mayer",version)
 
 
 #-- own imports --
 import Settings
 import MediaInfo
-
-from defaults import scriptdir, templatedir, version
+import defaults
 
 from LMCWidgetBase import LMCWidgetBase
 from AMCFile33 import AMCFile33, AMCRecord33
@@ -297,10 +299,25 @@ class LMCMain(LMCWidgetBase):
 
     def fileExport(self):
         """called when exporting current selection"""
+        # create user template directory
+        user_templatedir = fjoin(settings.userdir, 'templates')
+        if (not fexists(user_templatedir)):
+            self.log.info("Creating user templatedir '%s'"%user_templatedir)
+            os.mkdir(user_templatedir)
+
+        # copy system templates to user directory
+        for filename in os.listdir(templatedir):
+            # skip dot-files
+            if (filename[0] == '.'): continue
+            target_template = fjoin(user_templatedir, filename)
+            if (not fexists(target_template)):
+                self.log.info("Copying templates: '%s'"%filename)
+                shutil.copy(fjoin(templatedir,filename), target_template)
+        
         # create export dialog
         dlg = ExportDialog(self)
         if (dlg.exec_loop() == ExportDialog.Rejected): return
-        (exportFilter, sortKey, allEntries, reversed) = dlg.getOptions()
+        (exportTemplate, sortKey, allEntries, reversed) = dlg.getOptions()
 
         # get selected records, if required
         selectedList = []
@@ -325,32 +342,33 @@ class LMCMain(LMCWidgetBase):
             sortFcn = lambda a,b: int(a[0] - b[0])
         sortList.sort(sortFcn, None, reversed)
 
-        # call ouptut script
-        filterCommand  = pref['export'][exportFilter][0]
-        filterTemplate = pref['export'][exportFilter][1]
-        targetFile     = pref['export'][exportFilter][2]
-
-        # remove target file, if exists
-        if (fexists(targetFile)):
-            os.unlink(targetFile)    
-
-        exportScript = StdIOProcess(filterCommand,
-                                    [fjoin(templatedir,filterTemplate),
-                                     unicode(self.__file.name).encode(pref['systemEncoding'])],
-                                    os.environ, scriptdir)
+        # pass template through generator
+        user_template  = fjoin(user_templatedir, exportTemplate)
+        generatorScript = StdIOProcess(defaults.python,
+                                       [fjoin(installdir, 'templateParser.py'),
+                                        user_template, self.__file.name],
+                                       os.environ, '/tmp')
+        # parameter list for generatorScript
         paramList = [unicode(x[1]) for x in sortList]
-        execDlg = ExportProgressDialog(exportScript, paramList, modal=True)
+
+        # pass template through user filter chain
+        outputFilename = u'/tmp/%s'%splitext(exportTemplate)[0]
+        filterCommand = pref['export'][exportTemplate][0].replace('$1', outputFilename)
+        filterScript = StdIOProcess(os.environ['SHELL'], ['-c', "''%s''"%filterCommand],
+                                    os.environ, '/tmp')
+        execDlg = ExportProgressDialog(generatorScript, paramList, outputFilename,
+                                       filterScript, modal=True)
 
         # if process was aborted, stop
         if (execDlg.exec_loop() == execDlg.Rejected):
             self.log.info("Export aborted")
             return
 
-        print exportScript.stdout()
-        
         # query user for final destination of output file
-        if (fexists(targetFile)):
-            fileExt    = splitext(targetFile)[1]
+        targetFilename = pref['export'][exportTemplate][1].replace('$1', splitext(exportTemplate)[0])
+        print targetFilename
+        if (fexists(targetFilename)):
+            fileExt    = splitext(targetFilename)[1]
             dlg = QFileDialog(self.lastFolder, "*"+fileExt, self)
             dlg.setCaption(self.tr("Save exported file as"))
             dlg.setViewMode(QFileDialog.Detail)
@@ -362,13 +380,13 @@ class LMCMain(LMCWidgetBase):
                 filename = filename+fileExt
         
             # copy file to destination
-            shutil.move(targetFile, filename)
+            shutil.move(targetFilename, filename)
 
         # target file does not exist -> error
         else:
             dlg = QMessageBox.critical(self, "Error during export...",
-                                          "The target file %s does not exist. Please<br>"+
-                                          "check the debug output for further details.",
+                                       ("The target file %s does not exist. Please"+
+                                        "check the debug output for further details.")%targetFilename,
                                           QMessageBox.Ok)
             dlg.exec_loop()
         
@@ -1360,7 +1378,7 @@ Synopsis: lmc.py [-h|--help] [<input-file>]
 elif (('-v' in app.argv()[1:]) or ('--version' in app.argv()[1:])):
     print "Moviefly  (c) by Uwe Mayer"
     print "Version:  %s"%version
-    print "Revision: $Rev: 766 $"
+    print "Revision: $Rev: 773 $"
     print 
     sys.exit()
     
